==> ejc-procost-impl-3.0.0-20230428.025505-175-sources.jar: com/ejianc/business/procost/bean/ReportDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本分析报告明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_report_detail")
public class ReportDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="report_id")
    private Long reportId; // 主键ID
    @TableField(value="subject_name")
    private String subjectName; // 费用名称
    @TableField(value="ys_happen_mny_all")
    private BigDecimal ysHappenMnyAll; // 总收入预算
    @TableField(value="cb_happen_mny_all")
    private BigDecimal cbHappenMnyAll; // 总目标成本
    @TableField(value="ys_happen_mny")
    private BigDecimal ysHappenMny; // 累计产值报量
    @TableField(value="cb_happen_mny")
    private BigDecimal cbHappenMny; // 累计目标成本
    @TableField(value="happen_mny")
    private BigDecimal happenMny; // 累计实际成本
    @TableField(value="srmbdif_mny")
    private BigDecimal srmbdifMny; // 目标比收入
    @TableField(value="srmb_rate")
    private BigDecimal srmbRate; // 节超率（%）
    @TableField(value="srsjdif_mny")
    private BigDecimal srsjdifMny; // 实际比收入
    @TableField(value="srsj_rate")
    private BigDecimal srsjRate; // 节超率（%）
    @TableField(value="mbsjdif_mny")
    private BigDecimal mbsjdifMny; // 实际比目标
    @TableField(value="mbsj_rate")
    private BigDecimal mbsjRate; // 节超率（%）
    
    
    

    public Long getReportId() {
        return reportId;
    }

    public void setReportId(Long reportId) {
        this.reportId = reportId;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public BigDecimal getYsHappenMnyAll() {
        return ysHappenMnyAll;
    }

    public void setYsHappenMnyAll(BigDecimal ysHappenMnyAll) {
        this.ysHappenMnyAll = ysHappenMnyAll;
    }
    public BigDecimal getCbHappenMnyAll() {
        return cbHappenMnyAll;
    }

    public void setCbHappenMnyAll(BigDecimal cbHappenMnyAll) {
        this.cbHappenMnyAll = cbHappenMnyAll;
    }
    public BigDecimal getYsHappenMny() {
        return ysHappenMny;
    }

    public void setYsHappenMny(BigDecimal ysHappenMny) {
        this.ysHappenMny = ysHappenMny;
    }
    public BigDecimal getCbHappenMny() {
        return cbHappenMny;
    }

    public void setCbHappenMny(BigDecimal cbHappenMny) {
        this.cbHappenMny = cbHappenMny;
    }
    public BigDecimal getHappenMny() {
        return happenMny;
    }

    public void setHappenMny(BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    public BigDecimal getSrmbdifMny() {
        return srmbdifMny;
    }

    public void setSrmbdifMny(BigDecimal srmbdifMny) {
        this.srmbdifMny = srmbdifMny;
    }
    public BigDecimal getSrmbRate() {
        return srmbRate;
    }

    public void setSrmbRate(BigDecimal srmbRate) {
        this.srmbRate = srmbRate;
    }
    public BigDecimal getSrsjdifMny() {
        return srsjdifMny;
    }

    public void setSrsjdifMny(BigDecimal srsjdifMny) {
        this.srsjdifMny = srsjdifMny;
    }
    public BigDecimal getSrsjRate() {
        return srsjRate;
    }

    public void setSrsjRate(BigDecimal srsjRate) {
        this.srsjRate = srsjRate;
    }
    public BigDecimal getMbsjdifMny() {
        return mbsjdifMny;
    }

    public void setMbsjdifMny(BigDecimal mbsjdifMny) {
        this.mbsjdifMny = mbsjdifMny;
    }
    public BigDecimal getMbsjRate() {
        return mbsjRate;
    }

    public void setMbsjRate(BigDecimal mbsjRate) {
        this.mbsjRate = mbsjRate;
    }
    
}

==> ejc-procost-impl-3.0.0-20241024.102156-262-sources.jar: com/ejianc/business/procost/bean/ReportDetailEntity.java <==
package com.ejianc.business.procost.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 成本分析报告明细
 * 
 * @author generator
 * 
 */
 @TableName("ejc_procost_report_detail")
public class ReportDetailEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="report_id")
    private Long reportId; // 主键ID
    @TableField(value="subject_name")
    private String subjectName; // 费用名称
    @TableField(value="ys_happen_mny_all")
    private BigDecimal ysHappenMnyAll; // 总收入预算
    @TableField(value="cb_happen_mny_all")
    private BigDecimal cbHappenMnyAll; // 总目标成本
    @TableField(value="ys_happen_mny")
    private BigDecimal ysHappenMny; // 累计产值报量
    @TableField(value="cb_happen_mny")
    private BigDecimal cbHappenMny; // 累计目标成本
    @TableField(value="happen_mny")
    private BigDecimal happenMny; // 累计实际成本
    @TableField(value="cost_mny")
    private BigDecimal costMny; // 累计实际成本--录入
    @TableField(value="srmbdif_mny")
    private BigDecimal srmbdifMny; // 目标比收入
    @TableField(value="srmb_rate")
    private BigDecimal srmbRate; // 节超率（%）
    @TableField(value="srsjdif_mny")
    private BigDecimal srsjdifMny; // 实际比收入
    @TableField(value="srsj_rate")
    private BigDecimal srsjRate; // 节超率（%）
    @TableField(value="mbsjdif_mny")
    private BigDecimal mbsjdifMny; // 实际比目标
    @TableField(value="mbsj_rate")
    private BigDecimal mbsjRate; // 节超率（%）


    public BigDecimal getCostMny() {
        return costMny;
    }

    public void setCostMny(BigDecimal costMny) {
        this.costMny = costMny;
    }

    public Long getReportId() {
        return reportId;
    }

    public void setReportId(Long reportId) {
        this.reportId = reportId;
    }
    public String getSubjectName() {
        return subjectName;
    }

    public void setSubjectName(String subjectName) {
        this.subjectName = subjectName;
    }
    public BigDecimal getYsHappenMnyAll() {
        return ysHappenMnyAll;
    }

    public void setYsHappenMnyAll(BigDecimal ysHappenMnyAll) {
        this.ysHappenMnyAll = ysHappenMnyAll;
    }
    public BigDecimal getCbHappenMnyAll() {
        return cbHappenMnyAll;
    }

    public void setCbHappenMnyAll(BigDecimal cbHappenMnyAll) {
        this.cbHappenMnyAll = cbHappenMnyAll;
    }
    public BigDecimal getYsHappenMny() {
        return ysHappenMny;
    }

    public void setYsHappenMny(BigDecimal ysHappenMny) {
        this.ysHappenMny = ysHappenMny;
    }
    public BigDecimal getCbHappenMny() {
        return cbHappenMny;
    }

    public void setCbHappenMny(BigDecimal cbHappenMny) {
        this.cbHappenMny = cbHappenMny;
    }
    public BigDecimal getHappenMny() {
        return happenMny;
    }

    public void setHappenMny(BigDecimal happenMny) {
        this.happenMny = happenMny;
    }
    public BigDecimal getSrmbdifMny() {
        return srmbdifMny;
    }

    public void setSrmbdifMny(BigDecimal srmbdifMny) {
        this.srmbdifMny = srmbdifMny;
    }
    public BigDecimal getSrmbRate() {
        return srmbRate;
    }

    public void setSrmbRate(BigDecimal srmbRate) {
        this.srmbRate = srmbRate;
    }
    public BigDecimal getSrsjdifMny() {
        return srsjdifMny;
    }

    public void setSrsjdifMny(BigDecimal srsjdifMny) {
        this.srsjdifMny = srsjdifMny;
    }
    public BigDecimal getSrsjRate() {
        return srsjRate;
    }

    public void setSrsjRate(BigDecimal srsjRate) {
        this.srsjRate = srsjRate;
    }
    public BigDecimal getMbsjdifMny() {
        return mbsjdifMny;
    }

    public void setMbsjdifMny(BigDecimal mbsjdifMny) {
        this.mbsjdifMny = mbsjdifMny;
    }
    public BigDecimal getMbsjRate() {
        return mbsjRate;
    }

    public void setMbsjRate(BigDecimal mbsjRate) {
        this.mbsjRate = mbsjRate;
    }
    
}
